@@ -28,6 +28,8 @@ KEYWORDS_DICT = {"ANR in ": "Anr",
 
 INTERCEPTED_MAX_ROWS = 100
 
+LOG_FOLDER_NAME = "logcats"
+
 
 class Statistics:
     def increase(self, key_dict, key):
@@ -53,13 +55,16 @@ class LogcatMonitor:
     _key_dict = KEYWORDS_DICT
     _pool = ThreadPool(1)
 
-    def __init__(self, serial_number, parent_folder, key_dict=None, rows=INTERCEPTED_MAX_ROWS):
+    def __init__(self, serial_number=None, parent_folder=None, key_dict=None, rows=INTERCEPTED_MAX_ROWS):
         if key_dict is not None:
             for key in key_dict:
                 self._key_dict[key] = (key_dict[key])
         self._rows = rows
         # Create folder
-        self._self_folder = parent_folder + os.sep + "logcats"
+        if parent_folder is None:
+            self._self_folder = os.getcwd() + os.sep + LOG_FOLDER_NAME
+        else:
+            self._self_folder = parent_folder + os.sep + LOG_FOLDER_NAME
         if not os.path.isdir(self._self_folder):
             os.makedirs(self._self_folder)
         # Store serial number
@@ -93,6 +98,46 @@ class LogcatMonitor:
             time.sleep(3)
             print("Pool destroy")
 
+    def filter_file(self, file_name):
+        intercept = False
+        rows = 0
+        keys = self._key_dict.keys()
+        find_key = None
+        line_count = 0
+        with open(file_name, 'r', encoding='utf-8') as log_file:
+            line = log_file.readline()
+            while line:
+                line_count = line_count + 1
+                if not intercept:
+                    # Read data normally
+                    for key in keys:
+                        if line.find(key) != -1:
+                            message = "Detected：%s\n" % key
+                            print(message)
+                            self._logs.clear()
+                            intercept = True
+                            self._logs.append(line)
+                            rows = 1
+                            find_key = key
+                else:
+                    # An error has been detected.
+                    # Read the subsequent qualified logs
+                    if rows < self._rows:
+                        # Add the current line to the logs
+                        self._logs.append(line)
+                        rows = rows + 1
+                    else:
+                        # Finished reading the required logs
+                        intercept = False
+                        rows = 0
+                        # Increase error counter
+                        self._statistics.increase(self._key_dict, find_key)
+                        # Save as a file
+                        self._save_file(find_key, self._logs)
+                line = log_file.readline()
+        # Save statistics
+        self._save_statistics()
+
     def _filter_keyword(self):
         """
             Keep reading logcat output, find error information.
